==> zzyj-financeintegration-impl-3.0.0-20220616.032307-25-sources.jar: com/ejianc/business/financeintegration/PMPayApply/bean/PMJJFEntity.java <==
package com.ejianc.business.financeintegration.PMPayApply.bean;

import com.baomidou.mybatisplus.annotation.*;

import java.math.BigDecimal;

@TableName("PMJJF")
public class PMJJFEntity {

    private static final long serialVersionUID = 1L;

//    /**
//     * 主键
//     */
//    @TableField(
//            value = "ID",
//            fill = FieldFill.INSERT
//    )
//    @TableId(
//            type = IdType.NONE
//    )
//    private Long id;

//    /**
//     * 创建时间
//     */
//    @TableField(
//            value = "CJSJ",
//            fill = FieldFill.INSERT
//    )
//    private String createTime;
//
//    /**
//     * 修改时间
//     */
//    @TableField(
//            value = "XGSJ",
//            fill = FieldFill.INSERT
//    )
//    private String updateTime;

    /**
     * 项目ID
     */
    @TableField(value = "XMID")
    private String projectId;

    /**
     * 会计期间
     */
    @TableField(value = "KJQJ")
    private String period;

    /**
     * 金额
     */
    @TableField(value = "JE")
    private BigDecimal costMny;

    /**
     * 创建时间
     */
    @TableField(value = "SCRQ")
    private String createTime;

    /**
     * 修改时间
     */
    @TableField(value = "XGRQ",
            fill = FieldFill.INSERT)
    private String updateTime;

    /**
     * 是否PM引用
     */
    @TableField(value = "PMYY")
    private String cwFlag;


    public PMJJFEntity() {
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getCwFlag() {
        return cwFlag;
    }

    public void setCwFlag(String cwFlag) {
        this.cwFlag = cwFlag;
    }

    @Override
    public String toString() {
        return "PMJJFEntity{" +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", projectId='" + projectId + '\'' +
                ", period='" + period + '\'' +
                ", costMny='" + costMny + '\'' +
                ", cwFlag='" + cwFlag + '\'' +
                '}';
    }
}

==> zzyj-financeintegration-impl-3.0.0-20221130.105651-60-sources.jar: com/ejianc/business/financeintegration/PMPayApply/bean/PMJJFEntity.java <==
package com.ejianc.business.financeintegration.PMPayApply.bean;

import com.baomidou.mybatisplus.annotation.*;

import java.math.BigDecimal;

@TableName("PMJJF")
public class PMJJFEntity {

    private static final long serialVersionUID = 1L;

//    /**
//     * 主键
//     */
//    @TableField(
//            value = "ID",
//            fill = FieldFill.INSERT
//    )
//    @TableId(
//            type = IdType.NONE
//    )
//    private Long id;

//    /**
//     * 创建时间
//     */
//    @TableField(
//            value = "CJSJ",
//            fill = FieldFill.INSERT
//    )
//    private String createTime;
//
//    /**
//     * 修改时间
//     */
//    @TableField(
//            value = "XGSJ",
//            fill = FieldFill.INSERT
//    )
//    private String updateTime;

    /**
     * 项目ID
     */
    @TableField(value = "XMID")
    private String projectId;

    /**
     * 会计期间
     */
    @TableField(value = "KJQJ")
    private String period;

    /**
     * 费用名称
     */
    @TableField(value = "FYMC")
    private String fymc;

    /**
     * 金额
     */
    @TableField(value = "JE")
    private BigDecimal costMny;

    /**
     * 创建时间
     */
    @TableField(value = "SCRQ")
    private String createTime;

    /**
     * 修改时间
     */
    @TableField(value = "XGRQ",
            fill = FieldFill.INSERT)
    private String updateTime;

    /**
     * 是否PM引用
     */
    @TableField(value = "PMYY")
    private String cwFlag;


    public PMJJFEntity() {
    }

    public String getFymc() {
        return fymc;
    }

    public void setFymc(String fymc) {
        this.fymc = fymc;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getCwFlag() {
        return cwFlag;
    }

    public void setCwFlag(String cwFlag) {
        this.cwFlag = cwFlag;
    }

    @Override
    public String toString() {
        return "PMJJFEntity{" +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", projectId='" + projectId + '\'' +
                ", period='" + period + '\'' +
                ", costMny='" + costMny + '\'' +
                ", cwFlag='" + cwFlag + '\'' +
                '}';
    }
}
